\LoadClass[]{article}

\RequirePackage{amsfonts}
\RequirePackage{amsmath}
\RequirePackage{amsthm}
\RequirePackage{amssymb}
\RequirePackage{everypage}
\RequirePackage{geometry}
\RequirePackage{graphicx}
\RequirePackage{ifthen,array}
\RequirePackage{morefloats}
\RequirePackage{newtxtext}
\RequirePackage{newtxmath}
\RequirePackage{xcolor}
\RequirePackage{xspace}
\RequirePackage{stfloats}
\RequirePackage{url}


%% Page %%
\geometry{
  a4paper,
  top=25mm,
  left=69mm,
  textwidth=126mm,
  bottom=25mm,
}


%% Font %%
\renewcommand\normalsize{
  \@setfontsize\normalsize{9.5}{11}%
  \abovedisplayskip \baselineskip%
  \abovedisplayshortskip .5\baselineskip%
  \belowdisplayskip \abovedisplayskip
  \belowdisplayshortskip \abovedisplayshortskip
  \let\@listi\@list
}
\normalsize
\renewcommand\small{%
  \@setfontsize\small{9}{10.8}%
  \abovedisplayskip 8.5\p@ \@plus3\p@ \@minus4\p@
  \abovedisplayshortskip \z@ \@plus3\p@
  \belowdisplayshortskip 5\p@ \@plus3\p@ \@minus3\p@
  \def\@listi{\leftmargin\leftmargini
  \topsep 6\p@ \@plus2\p@ \@minus2\p@
    \parsep 3\p@ \@plus2\p@ \@minus\p@
    \itemsep \parsep
  }%
  \belowdisplayskip \abovedisplayskip
}


%% Font color %%
\usepackage[dvipdfmx]{hyperref}
\hypersetup{
  colorlinks=true, 
  citecolor=black,	
  filecolor=black,	
  linkcolor=black,	
%  pagecolor=black,	
  urlcolor=blue
}


\newcounter{ais@tmpCtr}
\newcounter{ais@auCtr}


%% Author %%
\def\ais@author{\stepcounter{ais@auCtr}%
  \global\emailfalse\@ifnextchar[{\ais@opt@author}{\ais@norm@author}
}

\def\ais@opt@author[#1]#2{\expandafter\gdef\csname 
  ais@@author\theais@auCtr\endcsname{\ignorespaces#2\textsuperscript{#1}}
  \setbox0=\hbox{#2}%
  \ifemail\gdef\t@corresp{#2}\fi%
}

\def\ais@norm@author#1{\expandafter\gdef\csname 
 ais@@author\theais@auCtr\endcsname{#1}
}

\let\author\ais@author

\def\ais@author@sep{%
  \ifnum\theais@tmpCtr=1\relax\else%
  \ifnum\count@ais@auCtr=\theais@tmpCtr%
  \ifnum\count@ais@auCtr=2\else\unskip,\fi\space%
  and\space\else\unskip,\space\fi\fi
}

\def\ais@printAuthors{\edef\count@ais@auCtr{\theais@auCtr}%
  \setcounter{ais@tmpCtr}{0}%
  \fontsize{13pt}{13}\selectfont\sffamily%
  \whiledo{\count@ais@auCtr>\theais@tmpCtr}
  {\stepcounter{ais@tmpCtr}%
  \ais@author@sep\csname ais@@author\theais@tmpCtr\endcsname}%
  \normalsize
}


%% Address %%
\def\ais@printAddress{}
\long\def\ais@address{\@ifnextchar[{\ais@opt@address}{\ais@norm@address}}
\long\def\ais@opt@address[#1]#2{\g@addto@macro\ais@printAddress{\fontsize{10.5pt}{10.5pt}\selectfont\sffamily%
  \par\leavevmode\llap{}\textsuperscript{#1\,}{#2}
}}

\let\address\ais@address

%% Mail %%
\newif\ifemail
\let\@email\@empty
\def\email#1{\global\emailtrue\gdef\@email{#1}%
}


%% Title %%
\renewcommand\maketitle{\par
  \begingroup
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
        \@maketitle
    \thispagestyle{plain}\@thanks
  \endgroup
  \setcounter{footnote}{0}%
}


\def\@maketitle{%
  \newpage
  \null
  \vspace*{-1.2em}%
  \begin{flushleft}%
    {\fontsize{22.2}{28.8}\sffamily\selectfont\@title\par}%
    \par\vspace{27pt}%
    \ais@printAuthors
    \par\vspace{13.5pt}%
    \ais@printAddress
    \par\vspace{12pt}%
    \textsf{* }\href{mailto:\@email}{\@email}
    \par%
  \end{flushleft}%
}


%% Abstract %%
\newbox\ais@absbox
\renewenvironment{abstract}{%
  \global\setbox\ais@absbox=\vbox\bgroup%
  \noindent{\fontsize{11.5pt}{11.5pt}\vspace{6pt}\textbf{\sffamily{\abstractname}}}\\
}
{\egroup\ais@printAbstract}

\def\ais@printAbstract{
  \par\vskip10pt
  \unvbox\ais@absbox\par
}


%% Keywords%%
\def\ais@printKeywords{}
\DeclareRobustCommand\keywords[1]{
  \par\vskip22pt
  \noindent{\fontsize{11.5pt}{11.5pt}\vspace{6pt}\textbf{\sffamily{Keywords}}\\ #1}
  \par\vskip30pt
}


%% Sectioning %%
\def\@seccntformat#1{\csname the#1\endcsname.\hskip.7em}
\renewcommand\section{\@startsection{section}{1}{\z@}%
  {-4.8ex \@plus -1ex \@minus -.2ex}%
  {1.5ex \@plus.2ex}%
  {\fontsize{13pt}{1.8pt}\sffamily\selectfont\boldmath\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
  {-3.25ex\@plus -1ex \@minus -.2ex}%
  {1.5ex \@plus .2ex}%
  {\normalfont\sffamily\fontsize{11.5pt}{11.5pt}\selectfont\boldmath\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
  {-3.25ex\@plus -1ex \@minus -.2ex}%
  {1.5ex \@plus .2ex}%
  {\normalfont\sffamily\fontsize{10.5pt}{10.5pt}\selectfont\boldmath\bfseries}}


%%  Bibtex %%
\renewenvironment{thebibliography}[1]
  {\subsection*{\refname}%
    \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
    \list{\@biblabel{\@arabic\c@enumiv}}%
    {\settowidth\labelwidth{\@biblabel{#1}}%
    \leftmargin\labelwidth
    \advance\leftmargin\labelsep
    \@openbib@code
    \usecounter{enumiv}%
    \let\p@enumiv\@empty
    \renewcommand\theenumiv{\@arabic\c@enumiv}}%
  \sloppy
  \clubpenalty4000
  \@clubpenalty \clubpenalty
  \widowpenalty4000%
  \sfcode`\.\@m
}
{\def\@noitemerr
  {\@latex@warning{Empty `thebibliography' environment}}%
  \endlist
}

\bibliographystyle{style/IEEEtran-ais}


%% Running heads %%
\def\ais@shorttitle{Missing short title!!}
\def\ais@shortauthor{Missing short authors!!}
\def\shorttitle#1{\gdef\ais@shorttitle{#1}}
\def\shortauthor#1{\gdef\ais@shortauthor{#1}}


%% Math and others %%
\thinmuskip=3mu
\medmuskip=4mu plus 2mu minus 4mu
\thickmuskip=5mu plus 3mu minus 1mu
\def\defaultscriptratio{.65}
\def\defaultscriptscriptratio{.5}
\parindent=9pt
\parskip=0pt
\hyphenpenalty=9999
\tolerance=1000
\emergencystretch=5pt
\lineskiplimit=-5pt


%% Full width figure %%
\newif\ifais@flt@full
\renewenvironment{figure*}[1][]
{\@dblfloat{figure}[#1]
  \ais@flt@fulltrue \leftskip -\dimexpr\Gm@lmargin-3.5pc
}
{\end@dblfloat}

\renewenvironment{table*}[1][]
{\@dblfloat{table}[#1]
  \ais@flt@fulltrue \leftskip -\dimexpr\Gm@lmargin-3.5pc
  \hsize=\dimexpr\textwidth+\Gm@lmargin-3.5pc
}
{\end@dblfloat}


%% Caption %%
\abovecaptionskip = 1pt
\belowcaptionskip = 1pt
\def\xxx{\def\endtabular{\crcr\egroup\egroup $\egroup} %$
  \def\tabular{\edef\@halignto{to\textwidth}\@tabular}
}

\extrarowheight 3pt
\long\def\@makecaption#1#2{% 
  \ifais@flt@full \leftskip -\dimexpr\Gm@lmargin-3.5pc\fi
  \vskip\abovecaptionskip
  \small
  \sbox\@tempboxa{\textsf{#1.} \sffamily#2}%
  \ifdim \wd\@tempboxa >\hsize
    \textbf{\textsf{#1.}} #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\ifais@flt@full\hskip -\dimexpr\Gm@lmargin-3.5pc\fi%
     \box\@tempboxa\hfill}%
  \fi
  \edef\@tempx{\expandafter\@carcube\@currenvir\@nil}%
  \ifthenelse{\equal{\@tempx}{tab}}{\aftergroup\small}{}%
  \vskip\belowcaptionskip
}


%% equal cell division for tablurarx %%
\usepackage{tabularx}
\newcolumntype{C}{>{\centering\arraybackslash}X}
\newcolumntype{L}{>{\raggedright\arraybackslash}X}
\newcolumntype{R}{>{\raggedleft\arraybackslash}X}


%% Float penalty %%
\setlength\floatsep      {1\baselineskip \@plus 2\p@ \@minus 2\p@}
\setlength\textfloatsep{1\baselineskip \@plus 2\p@ \@minus 4\p@}
\setlength\intextsep    {1\baselineskip \@plus 2\p@ \@minus 2\p@}


